@@ -12,6 +12,11 @@ import pygame
 
 
 def get_screen_resolution():
+    """
+
+    :return:
+    :rtype:
+    """
     info = pygame.display.Info()
     width = info.current_w
     height = info.current_h
