@@ -9,6 +9,7 @@ from pathlib import Path
 
 with open(Path(__file__).parent / "README.md", "r") as this_init_file:
     __doc__ += this_init_file.read()
+# del Path
 
 try:
     from draugr.tensorboard_utilities.exporting import *
@@ -19,9 +20,10 @@ except ImportError as ix:
         / "requirements"
         / f"requirements_{this_package_name}.txt"
     )
-    print(
-        f"Make sure requirements is installed for {this_package_name}, see {this_package_reqs}"
-    )  # TODO: PARSE WHAT is missing and print
+    if this_package_reqs.exists():
+        print(
+            f"Make sure requirements is installed for {this_package_name}, see {this_package_reqs}"
+        )  # TODO: PARSE WHAT is missing and print
     raise ix
 
 if __name__ == "__main__":
