@@ -6,7 +6,7 @@ from torch.optim.lr_scheduler import _LRScheduler
 
 
 class WarmupMultiStepLR(_LRScheduler):
-    """ """
+    """description"""
 
     def __init__(
         self,
